==> quarkus-core-1.13.2.Final-sources.jar: io/quarkus/runtime/logging/FileConfig$$accessor.java <==
package io.quarkus.runtime.logging;
public final class FileConfig$$accessor {
    private FileConfig$$accessor() {}
    @SuppressWarnings("unchecked")
    public static boolean get_enable(Object __instance) {
        return ((FileConfig)__instance).enable;
    }
    @SuppressWarnings("unchecked")
    public static void set_enable(Object __instance, boolean enable) {
        ((FileConfig)__instance).enable = enable;
    }
    @SuppressWarnings("unchecked")
    public static Object get_format(Object __instance) {
        return ((FileConfig)__instance).format;
    }
    @SuppressWarnings("unchecked")
    public static void set_format(Object __instance, Object format) {
        ((FileConfig)__instance).format = (String)format;
    }
    @SuppressWarnings("unchecked")
    public static Object get_level(Object __instance) {
        return ((FileConfig)__instance).level;
    }
    @SuppressWarnings("unchecked")
    public static void set_level(Object __instance, Object level) {
        ((FileConfig)__instance).level = (java.util.logging.Level)level;
    }
    @SuppressWarnings("unchecked")
    public static Object get_path(Object __instance) {
        return ((FileConfig)__instance).path;
    }
    @SuppressWarnings("unchecked")
    public static void set_path(Object __instance, Object path) {
        ((FileConfig)__instance).path = (java.io.File)path;
    }
    @SuppressWarnings("unchecked")
    public static Object get_async(Object __instance) {
        return ((FileConfig)__instance).async;
    }
    @SuppressWarnings("unchecked")
    public static void set_async(Object __instance, Object async) {
        ((FileConfig)__instance).async = (AsyncConfig)async;
    }
    @SuppressWarnings("unchecked")
    public static Object get_rotation(Object __instance) {
        return ((FileConfig)__instance).rotation;
    }
    @SuppressWarnings("unchecked")
    public static void set_rotation(Object __instance, Object rotation) {
        ((FileConfig)__instance).rotation = (io.quarkus.runtime.logging.FileConfig.RotationConfig)rotation;
    }
}

==> quarkus-core-2.14.1.Final-sources.jar: io/quarkus/runtime/logging/FileConfig$$accessor.java <==
package io.quarkus.runtime.logging;
public final class FileConfig$$accessor {
    private FileConfig$$accessor() {}
    @SuppressWarnings("unchecked")
    public static boolean get_enable(Object __instance) {
        return ((FileConfig)__instance).enable;
    }
    @SuppressWarnings("unchecked")
    public static void set_enable(Object __instance, boolean enable) {
        ((FileConfig)__instance).enable = enable;
    }
    @SuppressWarnings("unchecked")
    public static Object get_format(Object __instance) {
        return ((FileConfig)__instance).format;
    }
    @SuppressWarnings("unchecked")
    public static void set_format(Object __instance, Object format) {
        ((FileConfig)__instance).format = (String)format;
    }
    @SuppressWarnings("unchecked")
    public static Object get_level(Object __instance) {
        return ((FileConfig)__instance).level;
    }
    @SuppressWarnings("unchecked")
    public static void set_level(Object __instance, Object level) {
        ((FileConfig)__instance).level = (java.util.logging.Level)level;
    }
    @SuppressWarnings("unchecked")
    public static Object get_path(Object __instance) {
        return ((FileConfig)__instance).path;
    }
    @SuppressWarnings("unchecked")
    public static void set_path(Object __instance, Object path) {
        ((FileConfig)__instance).path = (java.io.File)path;
    }
    @SuppressWarnings("unchecked")
    public static Object get_filter(Object __instance) {
        return ((FileConfig)__instance).filter;
    }
    @SuppressWarnings("unchecked")
    public static void set_filter(Object __instance, Object filter) {
        ((FileConfig)__instance).filter = (java.util.Optional<String>)filter;
    }
    @SuppressWarnings("unchecked")
    public static Object get_async(Object __instance) {
        return ((FileConfig)__instance).async;
    }
    @SuppressWarnings("unchecked")
    public static void set_async(Object __instance, Object async) {
        ((FileConfig)__instance).async = (AsyncConfig)async;
    }
    @SuppressWarnings("unchecked")
    public static Object get_rotation(Object __instance) {
        return ((FileConfig)__instance).rotation;
    }
    @SuppressWarnings("unchecked")
    public static void set_rotation(Object __instance, Object rotation) {
        ((FileConfig)__instance).rotation = (io.quarkus.runtime.logging.FileConfig.RotationConfig)rotation;
    }
}
